==> haskell-servant-swagger-1.2.1-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-swagger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant-swagger
version:              1.2.1
visibility:           public
id:                   servant-swagger-1.2.1-3igmGKY4AO57DOyTaY13Mm
key:                  servant-swagger-1.2.1-3igmGKY4AO57DOyTaY13Mm
license:              BSD-3-Clause
copyright:            (c) 2015-2018, Servant contributors
maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:
    https://github.com/haskell-servant/servant/tree/master/servant-swagger#readme

synopsis:
    Generate a Swagger/OpenAPI/OAS 2.0 specification for your servant API.

description:
    Swagger is a project used to describe and document RESTful APIs. The core of the
    project is the [OpenAPI Specification (OAS)](https://swagger.io/docs/specification/about/).
    This library implements v2.0 of the spec. Unlike Servant it is language-agnostic and thus is
    quite popular among developers in different languages. It has also existed for a longer time
    and has more helpful tooling.

    This package provides means to generate a Swagger/OAS specification for a Servant API
    and also to partially test whether an API conforms with its specification.

    Generated Swagger specification then can be used for many things such as

    * displaying interactive documentation using [Swagger UI](http://swagger.io/swagger-ui/);

    * generating clients and servers in many languages using [Swagger Codegen](http://swagger.io/swagger-codegen/);

    * and [many others](http://swagger.io/open-source-integrations/).

category:             Web, Servant, Swagger
abi:                  44e6e3ff1b06f31d8f380289442d693a
exposed:              True
exposed-modules:
    Servant.Swagger Servant.Swagger.Internal
    Servant.Swagger.Internal.Orphans Servant.Swagger.Internal.Test
    Servant.Swagger.Internal.TypeLevel
    Servant.Swagger.Internal.TypeLevel.API
    Servant.Swagger.Internal.TypeLevel.Every
    Servant.Swagger.Internal.TypeLevel.TMap Servant.Swagger.Test
    Servant.Swagger.TypeLevel

import-dirs:          /usr/lib/ghc-9.4.8/site-local/servant-swagger-1.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/servant-swagger-1.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/servant-swagger-1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-swagger
hs-libraries:         HSservant-swagger-1.2.1-3igmGKY4AO57DOyTaY13Mm
depends:
    QuickCheck-2.14.3-6d1PIKLXLdiAlrbWNDjj9l
    aeson-2.1.2.1-BogEXKsQPCa9ALgQQ034ff
    aeson-pretty-0.8.10-1i80nKU9XQK9tJXNNhJ2PR base-4.17.2.1
    base-compat-0.12.2-3peTS4EQIw912qC0ETmbL5 bytestring-0.11.5.3
    hspec-2.10.9-6cXDJdoLErIA03da02F3Vw
    http-media-0.8.1.1-HrtNLIl5ZaI7zO5IcsBJqV
    insert-ordered-containers-0.2.5.3-BLiSf3vYz0GI4eKNNYbw54
    lens-5.2.3-CUB7er19pGW1jvefO3TVCG
    servant-0.20.2-CPxsnbRtMuI51iqHKme7ND
    singleton-bool-0.1.7-7gjjUYXDlWk7mQHeOj4gGY
    swagger2-2.8.9-BFVZg1iIS659Z9UpRyAFYM text-2.0.2
    unordered-containers-0.2.20-FzN23deFW3GkzXU7VwkDd

haddock-interfaces:
    /usr/share/doc/haskell-servant-swagger/html/servant-swagger.haddock

haddock-html:         /usr/share/doc/haskell-servant-swagger/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-swagger-1.2.1-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-swagger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant-swagger
version:              1.2.1
visibility:           public
id:                   servant-swagger-1.2.1-F1svVbzlyMf8w0WNVWZgxv
key:                  servant-swagger-1.2.1-F1svVbzlyMf8w0WNVWZgxv
license:              BSD-3-Clause
copyright:            (c) 2015-2018, Servant contributors
maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:
    https://github.com/haskell-servant/servant/tree/master/servant-swagger#readme

synopsis:
    Generate a Swagger/OpenAPI/OAS 2.0 specification for your servant API.

description:
    Swagger is a project used to describe and document RESTful APIs. The core of the
    project is the [OpenAPI Specification (OAS)](https://swagger.io/docs/specification/about/).
    This library implements v2.0 of the spec. Unlike Servant it is language-agnostic and thus is
    quite popular among developers in different languages. It has also existed for a longer time
    and has more helpful tooling.

    This package provides means to generate a Swagger/OAS specification for a Servant API
    and also to partially test whether an API conforms with its specification.

    Generated Swagger specification then can be used for many things such as

    * displaying interactive documentation using [Swagger UI](http://swagger.io/swagger-ui/);

    * generating clients and servers in many languages using [Swagger Codegen](http://swagger.io/swagger-codegen/);

    * and [many others](http://swagger.io/open-source-integrations/).

category:             Web, Servant, Swagger
abi:                  f836154549d945a7753b7b80035c79f9
exposed:              True
exposed-modules:
    Servant.Swagger Servant.Swagger.Internal
    Servant.Swagger.Internal.Orphans Servant.Swagger.Internal.Test
    Servant.Swagger.Internal.TypeLevel
    Servant.Swagger.Internal.TypeLevel.API
    Servant.Swagger.Internal.TypeLevel.Every
    Servant.Swagger.Internal.TypeLevel.TMap Servant.Swagger.Test
    Servant.Swagger.TypeLevel

import-dirs:          /usr/lib/ghc-9.4.8/site-local/servant-swagger-1.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/servant-swagger-1.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/servant-swagger-1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-swagger
hs-libraries:         HSservant-swagger-1.2.1-F1svVbzlyMf8w0WNVWZgxv
depends:
    QuickCheck-2.14.3-6d1PIKLXLdiAlrbWNDjj9l
    aeson-2.1.2.1-BogEXKsQPCa9ALgQQ034ff
    aeson-pretty-0.8.10-1i80nKU9XQK9tJXNNhJ2PR base-4.17.2.1
    base-compat-0.12.2-3peTS4EQIw912qC0ETmbL5 bytestring-0.11.5.3
    hspec-2.10.9-6cXDJdoLErIA03da02F3Vw
    http-media-0.8.1.1-HrtNLIl5ZaI7zO5IcsBJqV
    insert-ordered-containers-0.2.5.3-BLiSf3vYz0GI4eKNNYbw54
    lens-5.2.3-CUB7er19pGW1jvefO3TVCG
    servant-0.20.2-GihyK2ojIFo2wvCC49si27
    singleton-bool-0.1.7-BZyPYxjcnSj4tj63UBQgui
    swagger2-2.8.9-BFVZg1iIS659Z9UpRyAFYM text-2.0.2
    unordered-containers-0.2.20-FzN23deFW3GkzXU7VwkDd

haddock-interfaces:
    /usr/share/doc/haskell-servant-swagger/html/servant-swagger.haddock

haddock-html:         /usr/share/doc/haskell-servant-swagger/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
